#!/bin/bash


#  slackbuild script for elinks
# Author: Mark Tucker
# Created: Aug 12, 2004
# Changes:
#        Aug 12, 2004 - initial creation
#        Aug 27, 2005 - updated for version 10.5 and sbuild.functions

#
#----------------------------------------------------------------------

umask 0022

#----------------------------------------
# include the common functions
#----------------------------------------
if [ -r ./sbuild.functions ]; then
    . ./sbuild.functions
else
    echo Cannot read file `pwd`/sbuild.functions
    echo Exiting....
    echo
    exit
fi

#----------------------------------------
# Set locations for temp directories
#----------------------------------------
# location of source code archive
srcdir=`pwd`/SRC
workdir=`pwd`

#----------------------------------------
# Package variables
#----------------------------------------
source="elinks-0.10.5.tar.bz2"
pkgname="elinks"
pkgver="0.10.5"
release="1mht"
package="$pkgname-$pkgver-i486-$release.tgz"
realname="Mark Tucker"
echo Package: $package

#----------------------------------------
# setup path variables
#----------------------------------------
set_workdir

# unpack the source
echo Unpacking the source...
tar -xjf $srcdir/$source


cd $builddir

#----------------------------------------
# setup the build environment
#----------------------------------------
export CFLAGS="-O2 -march=i486 -mcpu=i686"
export CPPFLAGS="-O2 -march=i486 -mcpu=i686"
export CXXFLAGS=$CPPFLAGS


#----------------------------------------
# Build the package and install
#----------------------------------------
# configure 
conf_opts="--prefix=/usr \
    --sysconfdir=/etc \
    --localstatedir=/var \
    --without-gpm  \
    --without-lua \
    --enable-html-highlight \
    --enable-nntp"
run_configure $conf_opts

# make
run_make

# Set target directory
set_target

# install
run_makeinstall


echo finishing install...


# create install dir
mkdir $target/install

#----------------------------------------
# create slack-desc file to install
#----------------------------------------
cat > $target/install/slack-desc << END
      |-----handy-ruler------------------------------------------------------|
$pkgname: $pkgname $pkgver Text mode web browser
$pkgname:
$pkgname: "ELinks is an advanced and well-established feature-rich text mode 
$pkgname: web (HTTP/FTP/..) browser. ELinks can render both frames and 
$pkgname: tables..."
$pkgname: 
$pkgname: Compiled without lua support.
$pkgname: 
$pkgname: http://elinks.or.cz/index.html
$pkgname: 
$pkgname: Packaged by Mark Tucker for $slackver
END


# create documentation directory
create_docdir

# fix group on bin directories.
fix_bingrp

# strip  bin files
strip_bin

# strip lib files
strip_libs

# check for uncompressed man pages
compr_man

# makepkg
create_pkg

exit
